import 'dart:ui';
import 'package:flutter/material.dart';
import 'dart:math';

extension ColorMagic on Color {
  // Calculate the average rgb value of a color.
  double rgbAverage() {
    return (this.red + this.green + this.blue) / 3.0;
  }

  // Get the inverted color.
  Color invertedColor() {
    return Color.fromRGBO(
        255 - this.red, 255 - this.green, 255 - this.blue, 1.0);
  }

  // Get suitable black or white color for text display.
  Color suitableTextColor() {
    if (this.rgbAverage() > 127.5) {
      return Colors.black;
    } else {
      return Colors.white;
    }
  }
}

// The a color by enum value.
Color getColorByName(ColorName colorName) {
  return colors[ColorName.values.indexOf(colorName)];
}

// Get a random color from the library.
Color getRandomColor() {
  return colors[Random().nextInt(colors.length)];
}

// Lots of color names.
// See https://www.colorhexa.com/color-names
enum ColorName {
  AirForceBlue,
  AliceBlue,
  AlizarinCrimson,
  Almond,
  Amaranth,
  Amber,
  AmericanRose,
  Amethyst,
  AndroidGreen,
  AntiFlashWhite,
  AntiqueBrass,
  AntiqueFuchsia,
  AntiqueWhite,
  Ao,
  AppleGreen,
  Apricot,
  Aqua,
  Aquamarine,
  ArmyGreen,
  ArylideYellow,
  AshGrey,
  Asparagus,
  AtomicTangerine,
  Auburn,
  Aureolin,
  Aurometalsaurus,
  Awesome,
  Azure,
  AzureMist,
  BabyBlue,
  BabyBlueEyes,
  BabyPink,
  BallBlue,
  BananaMania,
  BananaYellow,
  BattleshipGrey,
  Bazaar,
  BeauBlue,
  Beaver,
  Beige,
  Bisque,
  Bistre,
  Bittersweet,
  Black,
  BlanchedAlmond,
  BleuDeFrance,
  BlizzardBlue,
  Blond,
  Blue,
  BlueBell,
  BlueGray,
  BlueGreen,
  BluePurple,
  BlueViolet,
  Blush,
  Bole,
  BondiBlue,
  Bone,
  BostonUniversityRed,
  BottleGreen,
  Boysenberry,
  BrandeisBlue,
  Brass,
  BrickRed,
  BrightCerulean,
  BrightGreen,
  BrightLavender,
  BrightMaroon,
  BrightPink,
  BrightTurquoise,
  BrightUbe,
  BrilliantLavender,
  BrilliantRose,
  BrinkPink,
  BritishRacingGreen,
  Bronze,
  Brown,
  BubbleGum,
  Bubbles,
  Buff,
  BulgarianRose,
  Burgundy,
  Burlywood,
  BurntOrange,
  BurntSienna,
  BurntUmber,
  Byzantine,
  Byzantium,
  CgBlue,
  CgRed,
  Cadet,
  CadetBlue,
  CadetGrey,
  CadmiumGreen,
  CadmiumOrange,
  CadmiumRed,
  CadmiumYellow,
  CafeAuLait,
  CafeNoir,
  CalPolyPomonaGreen,
  CambridgeBlue,
  Camel,
  CamouflageGreen,
  Canary,
  CanaryYellow,
  CandyAppleRed,
  CandyPink,
  Capri,
  CaputMortuum,
  Cardinal,
  CaribbeanGreen,
  Carmine,
  CarminePink,
  CarmineRed,
  CarnationPink,
  Carnelian,
  CarolinaBlue,
  CarrotOrange,
  Celadon,
  Celeste,
  CelestialBlue,
  Cerise,
  CerisePink,
  Cerulean,
  CeruleanBlue,
  Chamoisee,
  Champagne,
  Charcoal,
  Chartreuse,
  Cherry,
  CherryBlossomPink,
  Chestnut,
  Chocolate,
  ChromeYellow,
  Cinereous,
  Cinnabar,
  Cinnamon,
  Citrine,
  ClassicRose,
  Cobalt,
  CocoaBrown,
  Coffee,
  ColumbiaBlue,
  CoolBlack,
  CoolGrey,
  Copper,
  CopperRose,
  Coquelicot,
  Coral,
  CoralPink,
  CoralRed,
  Cordovan,
  Corn,
  CornellRed,
  Cornflower,
  CornflowerBlue,
  Cornsilk,
  CosmicLatte,
  CottonCandy,
  Cream,
  Crimson,
  CrimsonRed,
  CrimsonGlory,
  Cyan,
  Daffodil,
  Dandelion,
  DarkBlue,
  DarkBrown,
  DarkByzantium,
  DarkCandyAppleRed,
  DarkCerulean,
  DarkChestnut,
  DarkCoral,
  DarkCyan,
  DarkElectricBlue,
  DarkGoldenrod,
  DarkGray,
  DarkGreen,
  DarkJungleGreen,
  DarkKhaki,
  DarkLava,
  DarkLavender,
  DarkMagenta,
  DarkMidnightBlue,
  DarkOliveGreen,
  DarkOrange,
  DarkOrchid,
  DarkPastelBlue,
  DarkPastelGreen,
  DarkPastelPurple,
  DarkPastelRed,
  DarkPink,
  DarkPowderBlue,
  DarkRaspberry,
  DarkRed,
  DarkSalmon,
  DarkScarlet,
  DarkSeaGreen,
  DarkSienna,
  DarkSlateBlue,
  DarkSlateGray,
  DarkSpringGreen,
  DarkTan,
  DarkTangerine,
  DarkTaupe,
  DarkTerraCotta,
  DarkTurquoise,
  DarkViolet,
  DartmouthGreen,
  DavyGrey,
  DebianRed,
  DeepCarmine,
  DeepCarminePink,
  DeepCarrotOrange,
  DeepCerise,
  DeepChampagne,
  DeepChestnut,
  DeepCoffee,
  DeepFuchsia,
  DeepJungleGreen,
  DeepLilac,
  DeepMagenta,
  DeepPeach,
  DeepPink,
  DeepSaffron,
  DeepSkyBlue,
  Denim,
  Desert,
  DesertSand,
  DimGray,
  DodgerBlue,
  DogwoodRose,
  DollarBill,
  Drab,
  DukeBlue,
  EarthYellow,
  Ecru,
  Eggplant,
  Eggshell,
  EgyptianBlue,
  ElectricBlue,
  ElectricCrimson,
  ElectricCyan,
  ElectricGreen,
  ElectricIndigo,
  ElectricLavender,
  ElectricLime,
  ElectricPurple,
  ElectricUltramarine,
  ElectricViolet,
  ElectricYellow,
  Emerald,
  EtonBlue,
  Fallow,
  FaluRed,
  Famous,
  Fandango,
  FashionFuchsia,
  Fawn,
  Feldgrau,
  Fern,
  FernGreen,
  FerrariRed,
  FieldDrab,
  FireEngineRed,
  Firebrick,
  Flame,
  FlamingoPink,
  Flavescent,
  Flax,
  FloralWhite,
  FluorescentOrange,
  FluorescentPink,
  FluorescentYellow,
  Folly,
  ForestGreen,
  FrenchBeige,
  FrenchBlue,
  FrenchLilac,
  FrenchRose,
  Fuchsia,
  FuchsiaPink,
  Fulvous,
  FuzzyWuzzy,
  Gainsboro,
  Gamboge,
  GhostWhite,
  Ginger,
  Glaucous,
  Glitter,
  Gold,
  GoldenBrown,
  GoldenPoppy,
  GoldenYellow,
  Goldenrod,
  GrannySmithApple,
  Gray,
  GrayAsparagus,
  Green,
  GreenBlue,
  GreenYellow,
  Grullo,
  GuppieGreen,
  HalayaUbe,
  HanBlue,
  HanPurple,
  HansaYellow,
  Harlequin,
  HarvardCrimson,
  HarvestGold,
  HeartGold,
  Heliotrope,
  HollywoodCerise,
  Honeydew,
  HookerGreen,
  HotMagenta,
  HotPink,
  HunterGreen,
  Icterine,
  Inchworm,
  IndiaGreen,
  IndianRed,
  IndianYellow,
  Indigo,
  InternationalKleinBlue,
  InternationalOrange,
  Iris,
  Isabelline,
  IslamicGreen,
  Ivory,
  Jade,
  Jasmine,
  Jasper,
  JazzberryJam,
  Jonquil,
  JuneBud,
  JungleGreen,
  KuCrimson,
  KellyGreen,
  Khaki,
  LaSalleGreen,
  LanguidLavender,
  LapisLazuli,
  LaserLemon,
  LaurelGreen,
  Lava,
  Lavender,
  LavenderBlue,
  LavenderBlush,
  LavenderGray,
  LavenderIndigo,
  LavenderMagenta,
  LavenderMist,
  LavenderPink,
  LavenderPurple,
  LavenderRose,
  LawnGreen,
  Lemon,
  LemonYellow,
  LemonChiffon,
  LemonLime,
  LightCrimson,
  LightThulianPink,
  LightApricot,
  LightBlue,
  LightBrown,
  LightCarminePink,
  LightCoral,
  LightCornflowerBlue,
  LightCyan,
  LightFuchsiaPink,
  LightGoldenrodYellow,
  LightGray,
  LightGreen,
  LightKhaki,
  LightPastelPurple,
  LightPink,
  LightSalmon,
  LightSalmonPink,
  LightSeaGreen,
  LightSkyBlue,
  LightSlateGray,
  LightTaupe,
  LightYellow,
  Lilac,
  Lime,
  LimeGreen,
  LincolnGreen,
  Linen,
  Lion,
  Liver,
  Lust,
  MsuGreen,
  MacaroniAndCheese,
  Magenta,
  MagicMint,
  Magnolia,
  Mahogany,
  Maize,
  MajorelleBlue,
  Malachite,
  Manatee,
  MangoTango,
  Mantis,
  Maroon,
  Mauve,
  MauveTaupe,
  Mauvelous,
  MayaBlue,
  MeatBrown,
  MediumPersianBlue,
  MediumAquamarine,
  MediumBlue,
  MediumCandyAppleRed,
  MediumCarmine,
  MediumChampagne,
  MediumElectricBlue,
  MediumJungleGreen,
  MediumLavenderMagenta,
  MediumOrchid,
  MediumPurple,
  MediumRedViolet,
  MediumSeaGreen,
  MediumSlateBlue,
  MediumSpringBud,
  MediumSpringGreen,
  MediumTaupe,
  MediumTealBlue,
  MediumTurquoise,
  MediumVioletRed,
  Melon,
  MidnightBlue,
  MidnightGreen,
  MikadoYellow,
  Mint,
  MintCream,
  MintGreen,
  MistyRose,
  Moccasin,
  ModeBeige,
  MoonstoneBlue,
  MordantRed19,
  MossGreen,
  MountainMeadow,
  MountbattenPink,
  Mulberry,
  Munsell,
  Mustard,
  Myrtle,
  NadeshikoPink,
  NapierGreen,
  NaplesYellow,
  NavajoWhite,
  NavyBlue,
  NeonCarrot,
  NeonFuchsia,
  NeonGreen,
  NonPhotoBlue,
  NorthTexasGreen,
  OceanBoatBlue,
  Ochre,
  OfficeGreen,
  OldGold,
  OldLace,
  OldLavender,
  OldMauve,
  OldRose,
  Olive,
  OliveDrab,
  OliveGreen,
  Olivine,
  Onyx,
  OperaMauve,
  Orange,
  OrangeYellow,
  OrangePeel,
  OrangeRed,
  Orchid,
  OtterBrown,
  OuterSpace,
  OutrageousOrange,
  OxfordBlue,
  PacificBlue,
  PakistanGreen,
  PalatinateBlue,
  PalatinatePurple,
  PaleAqua,
  PaleBlue,
  PaleBrown,
  PaleCarmine,
  PaleCerulean,
  PaleChestnut,
  PaleCopper,
  PaleCornflowerBlue,
  PaleGold,
  PaleGoldenrod,
  PaleGreen,
  PaleLavender,
  PaleMagenta,
  PalePink,
  PalePlum,
  PaleRedViolet,
  PaleRobinEggBlue,
  PaleSilver,
  PaleSpringBud,
  PaleTaupe,
  PaleVioletRed,
  PansyPurple,
  PapayaWhip,
  ParisGreen,
  PastelBlue,
  PastelBrown,
  PastelGray,
  PastelGreen,
  PastelMagenta,
  PastelOrange,
  PastelPink,
  PastelPurple,
  PastelRed,
  PastelViolet,
  PastelYellow,
  Patriarch,
  PayneGrey,
  Peach,
  PeachPuff,
  PeachYellow,
  Pear,
  Pearl,
  PearlAqua,
  Peridot,
  Periwinkle,
  PersianBlue,
  PersianIndigo,
  PersianOrange,
  PersianPink,
  PersianPlum,
  PersianRed,
  PersianRose,
  Phlox,
  PhthaloBlue,
  PhthaloGreen,
  PiggyPink,
  PineGreen,
  Pink,
  PinkFlamingo,
  PinkSherbet,
  PinkPearl,
  Pistachio,
  Platinum,
  Plum,
  PortlandOrange,
  PowderBlue,
  PrincetonOrange,
  PrussianBlue,
  PsychedelicPurple,
  Puce,
  Pumpkin,
  Purple,
  PurpleHeart,
  PurpleMountainMajesty,
  PurpleMountainsMajesty,
  PurplePizzazz,
  PurpleTaupe,
  Rackley,
  RadicalRed,
  Raspberry,
  RaspberryGlace,
  RaspberryPink,
  RaspberryRose,
  RawSienna,
  RazzleDazzleRose,
  Razzmatazz,
  Red,
  RedOrange,
  RedBrown,
  RedViolet,
  RichBlack,
  RichCarmine,
  RichElectricBlue,
  RichLilac,
  RichMaroon,
  RifleGreen,
  RobinsEggBlue,
  Rose,
  RoseBonbon,
  RoseEbony,
  RoseGold,
  RoseMadder,
  RosePink,
  RoseQuartz,
  RoseTaupe,
  RoseVale,
  Rosewood,
  RossoCorsa,
  RosyBrown,
  RoyalAzure,
  RoyalBlue,
  RoyalFuchsia,
  RoyalPurple,
  Ruby,
  Ruddy,
  RuddyBrown,
  RuddyPink,
  Rufous,
  Russet,
  Rust,
  SacramentoStateGreen,
  SaddleBrown,
  SafetyOrange,
  Saffron,
  SaintPatrickBlue,
  Salmon,
  SalmonPink,
  Sand,
  SandDune,
  Sandstorm,
  SandyBrown,
  SandyTaupe,
  SapGreen,
  Sapphire,
  SatinSheenGold,
  Scarlet,
  SchoolBusYellow,
  ScreaminGreen,
  SeaBlue,
  SeaGreen,
  SealBrown,
  Seashell,
  SelectiveYellow,
  Sepia,
  Shadow,
  Shamrock,
  ShamrockGreen,
  ShockingPink,
  Sienna,
  Silver,
  Sinopia,
  Skobeloff,
  SkyBlue,
  SkyMagenta,
  SlateBlue,
  SlateGray,
  Smalt,
  SmokeyTopaz,
  SmokyBlack,
  Snow,
  SpiroDiscoBall,
  SpringBud,
  SpringGreen,
  SteelBlue,
  StilDeGrainYellow,
  Stizza,
  Stormcloud,
  Straw,
  Sunglow,
  Sunset,
  SunsetOrange,
  Tan,
  Tangelo,
  Tangerine,
  TangerineYellow,
  Taupe,
  TaupeGray,
  Tawny,
  TeaGreen,
  TeaRose,
  Teal,
  TealBlue,
  TealGreen,
  TerraCotta,
  Thistle,
  ThulianPink,
  TickleMePink,
  TiffanyBlue,
  TigerEye,
  Timberwolf,
  TitaniumYellow,
  Tomato,
  Toolbox,
  Topaz,
  TractorRed,
  TrolleyGrey,
  TropicalRainForest,
  TrueBlue,
  TuftsBlue,
  Tumbleweed,
  TurkishRose,
  Turquoise,
  TurquoiseBlue,
  TurquoiseGreen,
  TuscanRed,
  TwilightLavender,
  TyrianPurple,
  UaBlue,
  UaRed,
  UclaBlue,
  UclaGold,
  UfoGreen,
  UpForestGreen,
  UpMaroon,
  UscCardinal,
  UscGold,
  Ube,
  UltraPink,
  Ultramarine,
  UltramarineBlue,
  Umber,
  UnitedNationsBlue,
  UniversityOfCaliforniaGold,
  UnmellowYellow,
  UpsdellRed,
  Urobilin,
  UtahCrimson,
  Vanilla,
  VegasGold,
  VenetianRed,
  Verdigris,
  Vermilion,
  Veronica,
  Violet,
  VioletBlue,
  VioletRed,
  Viridian,
  VividAuburn,
  VividBurgundy,
  VividCerise,
  VividTangerine,
  VividViolet,
  WarmBlack,
  Waterspout,
  Wenge,
  Wheat,
  White,
  WhiteSmoke,
  WildStrawberry,
  WildWatermelon,
  WildBlueYonder,
  Wine,
  Wisteria,
  Xanadu,
  YaleBlue,
  Yellow,
  YellowOrange,
  YellowGreen,
  Zaffre,
  ZinnwalditeBrown,
}

// Lots of colors define.
Color AirForceBlue = Color(0xff5d8aa8);
Color AliceBlue = Color(0xfff0f8ff);
Color AlizarinCrimson = Color(0xffe32636);
Color Almond = Color(0xffefdecd);
Color Amaranth = Color(0xffe52b50);
Color Amber = Color(0xffffbf00);
Color AmericanRose = Color(0xffff033e);
Color Amethyst = Color(0xff9966cc);
Color AndroidGreen = Color(0xffa4c639);
Color AntiFlashWhite = Color(0xfff2f3f4);
Color AntiqueBrass = Color(0xffcd9575);
Color AntiqueFuchsia = Color(0xff915c83);
Color AntiqueWhite = Color(0xfffaebd7);
Color Ao = Color(0xff008000);
Color AppleGreen = Color(0xff8db600);
Color Apricot = Color(0xfffbceb1);
Color Aqua = Color(0xff00ffff);
Color Aquamarine = Color(0xff7fffd4);
Color ArmyGreen = Color(0xff4b5320);
Color ArylideYellow = Color(0xffe9d66b);
Color AshGrey = Color(0xffb2beb5);
Color Asparagus = Color(0xff87a96b);
Color AtomicTangerine = Color(0xffff9966);
Color Auburn = Color(0xffa52a2a);
Color Aureolin = Color(0xfffdee00);
Color Aurometalsaurus = Color(0xff6e7f80);
Color Awesome = Color(0xffff2052);
Color Azure = Color(0xff007fff);
Color AzureMist = Color(0xfff0ffff);
Color BabyBlue = Color(0xff89cff0);
Color BabyBlueEyes = Color(0xffa1caf1);
Color BabyPink = Color(0xfff4c2c2);
Color BallBlue = Color(0xff21abcd);
Color BananaMania = Color(0xfffae7b5);
Color BananaYellow = Color(0xffffe135);
Color BattleshipGrey = Color(0xff848482);
Color Bazaar = Color(0xff98777b);
Color BeauBlue = Color(0xffbcd4e6);
Color Beaver = Color(0xff9f8170);
Color Beige = Color(0xfff5f5dc);
Color Bisque = Color(0xffffe4c4);
Color Bistre = Color(0xff3d2b1f);
Color Bittersweet = Color(0xfffe6f5e);
Color Black = Color(0xff000000);
Color BlanchedAlmond = Color(0xffffebcd);
Color BleuDeFrance = Color(0xff318ce7);
Color BlizzardBlue = Color(0xfface5ee);
Color Blond = Color(0xfffaf0be);
Color Blue = Color(0xff0000ff);
Color BlueBell = Color(0xffa2a2d0);
Color BlueGray = Color(0xff6699cc);
Color BlueGreen = Color(0xff0d98ba);
Color BluePurple = Color(0xff8a2be2);
Color BlueViolet = Color(0xff8a2be2);
Color Blush = Color(0xffde5d83);
Color Bole = Color(0xff79443b);
Color BondiBlue = Color(0xff0095b6);
Color Bone = Color(0xffe3dac9);
Color BostonUniversityRed = Color(0xffcc0000);
Color BottleGreen = Color(0xff006a4e);
Color Boysenberry = Color(0xff873260);
Color BrandeisBlue = Color(0xff0070ff);
Color Brass = Color(0xffb5a642);
Color BrickRed = Color(0xffcb4154);
Color BrightCerulean = Color(0xff1dacd6);
Color BrightGreen = Color(0xff66ff00);
Color BrightLavender = Color(0xffbf94e4);
Color BrightMaroon = Color(0xffc32148);
Color BrightPink = Color(0xffff007f);
Color BrightTurquoise = Color(0xff08e8de);
Color BrightUbe = Color(0xffd19fe8);
Color BrilliantLavender = Color(0xfff4bbff);
Color BrilliantRose = Color(0xffff55a3);
Color BrinkPink = Color(0xfffb607f);
Color BritishRacingGreen = Color(0xff004225);
Color Bronze = Color(0xffcd7f32);
Color Brown = Color(0xffa52a2a);
Color BubbleGum = Color(0xffffc1cc);
Color Bubbles = Color(0xffe7feff);
Color Buff = Color(0xfff0dc82);
Color BulgarianRose = Color(0xff480607);
Color Burgundy = Color(0xff800020);
Color Burlywood = Color(0xffdeb887);
Color BurntOrange = Color(0xffcc5500);
Color BurntSienna = Color(0xffe97451);
Color BurntUmber = Color(0xff8a3324);
Color Byzantine = Color(0xffbd33a4);
Color Byzantium = Color(0xff702963);
Color CgBlue = Color(0xff007aa5);
Color CgRed = Color(0xffe03c31);
Color Cadet = Color(0xff536872);
Color CadetBlue = Color(0xff5f9ea0);
Color CadetGrey = Color(0xff91a3b0);
Color CadmiumGreen = Color(0xff006b3c);
Color CadmiumOrange = Color(0xffed872d);
Color CadmiumRed = Color(0xffe30022);
Color CadmiumYellow = Color(0xfffff600);
Color CafeAuLait = Color(0xffa67b5b);
Color CafeNoir = Color(0xff4b3621);
Color CalPolyPomonaGreen = Color(0xff1e4d2b);
Color CambridgeBlue = Color(0xffa3c1ad);
Color Camel = Color(0xffc19a6b);
Color CamouflageGreen = Color(0xff78866b);
Color Canary = Color(0xffffff99);
Color CanaryYellow = Color(0xffffef00);
Color CandyAppleRed = Color(0xffff0800);
Color CandyPink = Color(0xffe4717a);
Color Capri = Color(0xff00bfff);
Color CaputMortuum = Color(0xff592720);
Color Cardinal = Color(0xffc41e3a);
Color CaribbeanGreen = Color(0xff00cc99);
Color Carmine = Color(0xffff0040);
Color CarminePink = Color(0xffeb4c42);
Color CarmineRed = Color(0xffff0038);
Color CarnationPink = Color(0xffffa6c9);
Color Carnelian = Color(0xffb31b1b);
Color CarolinaBlue = Color(0xff99badd);
Color CarrotOrange = Color(0xffed9121);
Color Celadon = Color(0xfface1af);
Color Celeste = Color(0xffb2ffff);
Color CelestialBlue = Color(0xff4997d0);
Color Cerise = Color(0xffde3163);
Color CerisePink = Color(0xffec3b83);
Color Cerulean = Color(0xff007ba7);
Color CeruleanBlue = Color(0xff2a52be);
Color Chamoisee = Color(0xffa0785a);
Color Champagne = Color(0xfffad6a5);
Color Charcoal = Color(0xff36454f);
Color Chartreuse = Color(0xff7fff00);
Color Cherry = Color(0xffde3163);
Color CherryBlossomPink = Color(0xffffb7c5);
Color Chestnut = Color(0xffcd5c5c);
Color Chocolate = Color(0xffd2691e);
Color ChromeYellow = Color(0xffffa700);
Color Cinereous = Color(0xff98817b);
Color Cinnabar = Color(0xffe34234);
Color Cinnamon = Color(0xffd2691e);
Color Citrine = Color(0xffe4d00a);
Color ClassicRose = Color(0xfffbcce7);
Color Cobalt = Color(0xff0047ab);
Color CocoaBrown = Color(0xffd2691e);
Color Coffee = Color(0xff6f4e37);
Color ColumbiaBlue = Color(0xff9bddff);
Color CoolBlack = Color(0xff002e63);
Color CoolGrey = Color(0xff8c92ac);
Color Copper = Color(0xffb87333);
Color CopperRose = Color(0xff996666);
Color Coquelicot = Color(0xffff3800);
Color Coral = Color(0xffff7f50);
Color CoralPink = Color(0xfff88379);
Color CoralRed = Color(0xffff4040);
Color Cordovan = Color(0xff893f45);
Color Corn = Color(0xfffbec5d);
Color CornellRed = Color(0xffb31b1b);
Color Cornflower = Color(0xff9aceeb);
Color CornflowerBlue = Color(0xff6495ed);
Color Cornsilk = Color(0xfffff8dc);
Color CosmicLatte = Color(0xfffff8e7);
Color CottonCandy = Color(0xffffbcd9);
Color Cream = Color(0xfffffdd0);
Color Crimson = Color(0xffdc143c);
Color CrimsonRed = Color(0xff990000);
Color CrimsonGlory = Color(0xffbe0032);
Color Cyan = Color(0xff00ffff);
Color Daffodil = Color(0xffffff31);
Color Dandelion = Color(0xfff0e130);
Color DarkBlue = Color(0xff00008b);
Color DarkBrown = Color(0xff654321);
Color DarkByzantium = Color(0xff5d3954);
Color DarkCandyAppleRed = Color(0xffa40000);
Color DarkCerulean = Color(0xff08457e);
Color DarkChestnut = Color(0xff986960);
Color DarkCoral = Color(0xffcd5b45);
Color DarkCyan = Color(0xff008b8b);
Color DarkElectricBlue = Color(0xff536878);
Color DarkGoldenrod = Color(0xffb8860b);
Color DarkGray = Color(0xffa9a9a9);
Color DarkGreen = Color(0xff013220);
Color DarkJungleGreen = Color(0xff1a2421);
Color DarkKhaki = Color(0xffbdb76b);
Color DarkLava = Color(0xff483c32);
Color DarkLavender = Color(0xff734f96);
Color DarkMagenta = Color(0xff8b008b);
Color DarkMidnightBlue = Color(0xff003366);
Color DarkOliveGreen = Color(0xff556b2f);
Color DarkOrange = Color(0xffff8c00);
Color DarkOrchid = Color(0xff9932cc);
Color DarkPastelBlue = Color(0xff779ecb);
Color DarkPastelGreen = Color(0xff03c03c);
Color DarkPastelPurple = Color(0xff966fd6);
Color DarkPastelRed = Color(0xffc23b22);
Color DarkPink = Color(0xffe75480);
Color DarkPowderBlue = Color(0xff003399);
Color DarkRaspberry = Color(0xff872657);
Color DarkRed = Color(0xff8b0000);
Color DarkSalmon = Color(0xffe9967a);
Color DarkScarlet = Color(0xff560319);
Color DarkSeaGreen = Color(0xff8fbc8f);
Color DarkSienna = Color(0xff3c1414);
Color DarkSlateBlue = Color(0xff483d8b);
Color DarkSlateGray = Color(0xff2f4f4f);
Color DarkSpringGreen = Color(0xff177245);
Color DarkTan = Color(0xff918151);
Color DarkTangerine = Color(0xffffa812);
Color DarkTaupe = Color(0xff483c32);
Color DarkTerraCotta = Color(0xffcc4e5c);
Color DarkTurquoise = Color(0xff00ced1);
Color DarkViolet = Color(0xff9400d3);
Color DartmouthGreen = Color(0xff00693e);
Color DavyGrey = Color(0xff555555);
Color DebianRed = Color(0xffd70a53);
Color DeepCarmine = Color(0xffa9203e);
Color DeepCarminePink = Color(0xffef3038);
Color DeepCarrotOrange = Color(0xffe9692c);
Color DeepCerise = Color(0xffda3287);
Color DeepChampagne = Color(0xfffad6a5);
Color DeepChestnut = Color(0xffb94e48);
Color DeepCoffee = Color(0xff704241);
Color DeepFuchsia = Color(0xffc154c1);
Color DeepJungleGreen = Color(0xff004b49);
Color DeepLilac = Color(0xff9955bb);
Color DeepMagenta = Color(0xffcc00cc);
Color DeepPeach = Color(0xffffcba4);
Color DeepPink = Color(0xffff1493);
Color DeepSaffron = Color(0xffff9933);
Color DeepSkyBlue = Color(0xff00bfff);
Color Denim = Color(0xff1560bd);
Color Desert = Color(0xffc19a6b);
Color DesertSand = Color(0xffedc9af);
Color DimGray = Color(0xff696969);
Color DodgerBlue = Color(0xff1e90ff);
Color DogwoodRose = Color(0xffd71868);
Color DollarBill = Color(0xff85bb65);
Color Drab = Color(0xff967117);
Color DukeBlue = Color(0xff00009c);
Color EarthYellow = Color(0xffe1a95f);
Color Ecru = Color(0xffc2b280);
Color Eggplant = Color(0xff614051);
Color Eggshell = Color(0xfff0ead6);
Color EgyptianBlue = Color(0xff1034a6);
Color ElectricBlue = Color(0xff7df9ff);
Color ElectricCrimson = Color(0xffff003f);
Color ElectricCyan = Color(0xff00ffff);
Color ElectricGreen = Color(0xff00ff00);
Color ElectricIndigo = Color(0xff6f00ff);
Color ElectricLavender = Color(0xfff4bbff);
Color ElectricLime = Color(0xffccff00);
Color ElectricPurple = Color(0xffbf00ff);
Color ElectricUltramarine = Color(0xff3f00ff);
Color ElectricViolet = Color(0xff8f00ff);
Color ElectricYellow = Color(0xffffff00);
Color Emerald = Color(0xff50c878);
Color EtonBlue = Color(0xff96c8a2);
Color Fallow = Color(0xffc19a6b);
Color FaluRed = Color(0xff801818);
Color Famous = Color(0xffff00ff);
Color Fandango = Color(0xffb53389);
Color FashionFuchsia = Color(0xfff400a1);
Color Fawn = Color(0xffe5aa70);
Color Feldgrau = Color(0xff4d5d53);
Color Fern = Color(0xff71bc78);
Color FernGreen = Color(0xff4f7942);
Color FerrariRed = Color(0xffff2800);
Color FieldDrab = Color(0xff6c541e);
Color FireEngineRed = Color(0xffce2029);
Color Firebrick = Color(0xffb22222);
Color Flame = Color(0xffe25822);
Color FlamingoPink = Color(0xfffc8eac);
Color Flavescent = Color(0xfff7e98e);
Color Flax = Color(0xffeedc82);
Color FloralWhite = Color(0xfffffaf0);
Color FluorescentOrange = Color(0xffffbf00);
Color FluorescentPink = Color(0xffff1493);
Color FluorescentYellow = Color(0xffccff00);
Color Folly = Color(0xffff004f);
Color ForestGreen = Color(0xff228b22);
Color FrenchBeige = Color(0xffa67b5b);
Color FrenchBlue = Color(0xff0072bb);
Color FrenchLilac = Color(0xff86608e);
Color FrenchRose = Color(0xfff64a8a);
Color Fuchsia = Color(0xffff00ff);
Color FuchsiaPink = Color(0xffff77ff);
Color Fulvous = Color(0xffe48400);
Color FuzzyWuzzy = Color(0xffcc6666);
Color Gainsboro = Color(0xffdcdcdc);
Color Gamboge = Color(0xffe49b0f);
Color GhostWhite = Color(0xfff8f8ff);
Color Ginger = Color(0xffb06500);
Color Glaucous = Color(0xff6082b6);
Color Glitter = Color(0xffe6e8fa);
Color Gold = Color(0xffffd700);
Color GoldenBrown = Color(0xff996515);
Color GoldenPoppy = Color(0xfffcc200);
Color GoldenYellow = Color(0xffffdf00);
Color Goldenrod = Color(0xffdaa520);
Color GrannySmithApple = Color(0xffa8e4a0);
Color Gray = Color(0xff808080);
Color GrayAsparagus = Color(0xff465945);
Color Green = Color(0xff00ff00);
Color GreenBlue = Color(0xff1164b4);
Color GreenYellow = Color(0xffadff2f);
Color Grullo = Color(0xffa99a86);
Color GuppieGreen = Color(0xff00ff7f);
Color HalayaUbe = Color(0xff663854);
Color HanBlue = Color(0xff446ccf);
Color HanPurple = Color(0xff5218fa);
Color HansaYellow = Color(0xffe9d66b);
Color Harlequin = Color(0xff3fff00);
Color HarvardCrimson = Color(0xffc90016);
Color HarvestGold = Color(0xffda9100);
Color HeartGold = Color(0xff808000);
Color Heliotrope = Color(0xffdf73ff);
Color HollywoodCerise = Color(0xfff400a1);
Color Honeydew = Color(0xfff0fff0);
Color HookerGreen = Color(0xff49796b);
Color HotMagenta = Color(0xffff1dce);
Color HotPink = Color(0xffff69b4);
Color HunterGreen = Color(0xff355e3b);
Color Icterine = Color(0xfffcf75e);
Color Inchworm = Color(0xffb2ec5d);
Color IndiaGreen = Color(0xff138808);
Color IndianRed = Color(0xffcd5c5c);
Color IndianYellow = Color(0xffe3a857);
Color Indigo = Color(0xff4b0082);
Color InternationalKleinBlue = Color(0xff002fa7);
Color InternationalOrange = Color(0xffff4f00);
Color Iris = Color(0xff5a4fcf);
Color Isabelline = Color(0xfff4f0ec);
Color IslamicGreen = Color(0xff009000);
Color Ivory = Color(0xfffffff0);
Color Jade = Color(0xff00a86b);
Color Jasmine = Color(0xfff8de7e);
Color Jasper = Color(0xffd73b3e);
Color JazzberryJam = Color(0xffa50b5e);
Color Jonquil = Color(0xfffada5e);
Color JuneBud = Color(0xffbdda57);
Color JungleGreen = Color(0xff29ab87);
Color KuCrimson = Color(0xffe8000d);
Color KellyGreen = Color(0xff4cbb17);
Color Khaki = Color(0xffc3b091);
Color LaSalleGreen = Color(0xff087830);
Color LanguidLavender = Color(0xffd6cadd);
Color LapisLazuli = Color(0xff26619c);
Color LaserLemon = Color(0xfffefe22);
Color LaurelGreen = Color(0xffa9ba9d);
Color Lava = Color(0xffcf1020);
Color Lavender = Color(0xffe6e6fa);
Color LavenderBlue = Color(0xffccccff);
Color LavenderBlush = Color(0xfffff0f5);
Color LavenderGray = Color(0xffc4c3d0);
Color LavenderIndigo = Color(0xff9457eb);
Color LavenderMagenta = Color(0xffee82ee);
Color LavenderMist = Color(0xffe6e6fa);
Color LavenderPink = Color(0xfffbaed2);
Color LavenderPurple = Color(0xff967bb6);
Color LavenderRose = Color(0xfffba0e3);
Color LawnGreen = Color(0xff7cfc00);
Color Lemon = Color(0xfffff700);
Color LemonYellow = Color(0xfffff44f);
Color LemonChiffon = Color(0xfffffacd);
Color LemonLime = Color(0xffbfff00);
Color LightCrimson = Color(0xfff56991);
Color LightThulianPink = Color(0xffe68fac);
Color LightApricot = Color(0xfffdd5b1);
Color LightBlue = Color(0xffadd8e6);
Color LightBrown = Color(0xffb5651d);
Color LightCarminePink = Color(0xffe66771);
Color LightCoral = Color(0xfff08080);
Color LightCornflowerBlue = Color(0xff93ccea);
Color LightCyan = Color(0xffe0ffff);
Color LightFuchsiaPink = Color(0xfff984ef);
Color LightGoldenrodYellow = Color(0xfffafad2);
Color LightGray = Color(0xffd3d3d3);
Color LightGreen = Color(0xff90ee90);
Color LightKhaki = Color(0xfff0e68c);
Color LightPastelPurple = Color(0xffb19cd9);
Color LightPink = Color(0xffffb6c1);
Color LightSalmon = Color(0xffffa07a);
Color LightSalmonPink = Color(0xffff9999);
Color LightSeaGreen = Color(0xff20b2aa);
Color LightSkyBlue = Color(0xff87cefa);
Color LightSlateGray = Color(0xff778899);
Color LightTaupe = Color(0xffb38b6d);
Color LightYellow = Color(0xffffffed);
Color Lilac = Color(0xffc8a2c8);
Color Lime = Color(0xffbfff00);
Color LimeGreen = Color(0xff32cd32);
Color LincolnGreen = Color(0xff195905);
Color Linen = Color(0xfffaf0e6);
Color Lion = Color(0xffc19a6b);
Color Liver = Color(0xff534b4f);
Color Lust = Color(0xffe62020);
Color MsuGreen = Color(0xff18453b);
Color MacaroniAndCheese = Color(0xffffbd88);
Color Magenta = Color(0xffff00ff);
Color MagicMint = Color(0xffaaf0d1);
Color Magnolia = Color(0xfff8f4ff);
Color Mahogany = Color(0xffc04000);
Color Maize = Color(0xfffbec5d);
Color MajorelleBlue = Color(0xff6050dc);
Color Malachite = Color(0xff0bda51);
Color Manatee = Color(0xff979aaa);
Color MangoTango = Color(0xffff8243);
Color Mantis = Color(0xff74c365);
Color Maroon = Color(0xff800000);
Color Mauve = Color(0xffe0b0ff);
Color MauveTaupe = Color(0xff915f6d);
Color Mauvelous = Color(0xffef98aa);
Color MayaBlue = Color(0xff73c2fb);
Color MeatBrown = Color(0xffe5b73b);
Color MediumPersianBlue = Color(0xff0067a5);
Color MediumAquamarine = Color(0xff66ddaa);
Color MediumBlue = Color(0xff0000cd);
Color MediumCandyAppleRed = Color(0xffe2062c);
Color MediumCarmine = Color(0xffaf4035);
Color MediumChampagne = Color(0xfff3e5ab);
Color MediumElectricBlue = Color(0xff035096);
Color MediumJungleGreen = Color(0xff1c352d);
Color MediumLavenderMagenta = Color(0xffdda0dd);
Color MediumOrchid = Color(0xffba55d3);
Color MediumPurple = Color(0xff9370db);
Color MediumRedViolet = Color(0xffbb3385);
Color MediumSeaGreen = Color(0xff3cb371);
Color MediumSlateBlue = Color(0xff7b68ee);
Color MediumSpringBud = Color(0xffc9dc87);
Color MediumSpringGreen = Color(0xff00fa9a);
Color MediumTaupe = Color(0xff674c47);
Color MediumTealBlue = Color(0xff0054b4);
Color MediumTurquoise = Color(0xff48d1cc);
Color MediumVioletRed = Color(0xffc71585);
Color Melon = Color(0xfffdbcb4);
Color MidnightBlue = Color(0xff191970);
Color MidnightGreen = Color(0xff004953);
Color MikadoYellow = Color(0xffffc40c);
Color Mint = Color(0xff3eb489);
Color MintCream = Color(0xfff5fffa);
Color MintGreen = Color(0xff98ff98);
Color MistyRose = Color(0xffffe4e1);
Color Moccasin = Color(0xfffaebd7);
Color ModeBeige = Color(0xff967117);
Color MoonstoneBlue = Color(0xff73a9c2);
Color MordantRed19 = Color(0xffae0c00);
Color MossGreen = Color(0xffaddfad);
Color MountainMeadow = Color(0xff30ba8f);
Color MountbattenPink = Color(0xff997a8d);
Color Mulberry = Color(0xffc54b8c);
Color Munsell = Color(0xfff2f3f4);
Color Mustard = Color(0xffffdb58);
Color Myrtle = Color(0xff21421e);
Color NadeshikoPink = Color(0xfff6adc6);
Color NapierGreen = Color(0xff2a8000);
Color NaplesYellow = Color(0xfffada5e);
Color NavajoWhite = Color(0xffffdead);
Color NavyBlue = Color(0xff000080);
Color NeonCarrot = Color(0xffffa343);
Color NeonFuchsia = Color(0xfffe59c2);
Color NeonGreen = Color(0xff39ff14);
Color NonPhotoBlue = Color(0xffa4dded);
Color NorthTexasGreen = Color(0xff059033);
Color OceanBoatBlue = Color(0xff0077be);
Color Ochre = Color(0xffcc7722);
Color OfficeGreen = Color(0xff008000);
Color OldGold = Color(0xffcfb53b);
Color OldLace = Color(0xfffdf5e6);
Color OldLavender = Color(0xff796878);
Color OldMauve = Color(0xff673147);
Color OldRose = Color(0xffc08081);
Color Olive = Color(0xff808000);
Color OliveDrab = Color(0xff6b8e23);
Color OliveGreen = Color(0xffbab86c);
Color Olivine = Color(0xff9ab973);
Color Onyx = Color(0xff0f0f0f);
Color OperaMauve = Color(0xffb784a7);
Color Orange = Color(0xffffa500);
Color OrangeYellow = Color(0xfff8d568);
Color OrangePeel = Color(0xffff9f00);
Color OrangeRed = Color(0xffff4500);
Color Orchid = Color(0xffda70d6);
Color OtterBrown = Color(0xff654321);
Color OuterSpace = Color(0xff414a4c);
Color OutrageousOrange = Color(0xffff6e4a);
Color OxfordBlue = Color(0xff002147);
Color PacificBlue = Color(0xff1ca9c9);
Color PakistanGreen = Color(0xff006600);
Color PalatinateBlue = Color(0xff273be2);
Color PalatinatePurple = Color(0xff682860);
Color PaleAqua = Color(0xffbcd4e6);
Color PaleBlue = Color(0xffafeeee);
Color PaleBrown = Color(0xff987654);
Color PaleCarmine = Color(0xffaf4035);
Color PaleCerulean = Color(0xff9bc4e2);
Color PaleChestnut = Color(0xffddadaf);
Color PaleCopper = Color(0xffda8a67);
Color PaleCornflowerBlue = Color(0xffabcdef);
Color PaleGold = Color(0xffe6be8a);
Color PaleGoldenrod = Color(0xffeee8aa);
Color PaleGreen = Color(0xff98fb98);
Color PaleLavender = Color(0xffdcd0ff);
Color PaleMagenta = Color(0xfff984e5);
Color PalePink = Color(0xfffadadd);
Color PalePlum = Color(0xffdda0dd);
Color PaleRedViolet = Color(0xffdb7093);
Color PaleRobinEggBlue = Color(0xff96ded1);
Color PaleSilver = Color(0xffc9c0bb);
Color PaleSpringBud = Color(0xffecebbd);
Color PaleTaupe = Color(0xffbc987e);
Color PaleVioletRed = Color(0xffdb7093);
Color PansyPurple = Color(0xff78184a);
Color PapayaWhip = Color(0xffffefd5);
Color ParisGreen = Color(0xff50c878);
Color PastelBlue = Color(0xffaec6cf);
Color PastelBrown = Color(0xff836953);
Color PastelGray = Color(0xffcfcfc4);
Color PastelGreen = Color(0xff77dd77);
Color PastelMagenta = Color(0xfff49ac2);
Color PastelOrange = Color(0xffffb347);
Color PastelPink = Color(0xffffd1dc);
Color PastelPurple = Color(0xffb39eb5);
Color PastelRed = Color(0xffff6961);
Color PastelViolet = Color(0xffcb99c9);
Color PastelYellow = Color(0xfffdfd96);
Color Patriarch = Color(0xff800080);
Color PayneGrey = Color(0xff536878);
Color Peach = Color(0xffffe5b4);
Color PeachPuff = Color(0xffffdab9);
Color PeachYellow = Color(0xfffadfad);
Color Pear = Color(0xffd1e231);
Color Pearl = Color(0xffeae0c8);
Color PearlAqua = Color(0xff88d8c0);
Color Peridot = Color(0xffe6e200);
Color Periwinkle = Color(0xffccccff);
Color PersianBlue = Color(0xff1c39bb);
Color PersianIndigo = Color(0xff32127a);
Color PersianOrange = Color(0xffd99058);
Color PersianPink = Color(0xfff77fbe);
Color PersianPlum = Color(0xff701c1c);
Color PersianRed = Color(0xffcc3333);
Color PersianRose = Color(0xfffe28a2);
Color Phlox = Color(0xffdf00ff);
Color PhthaloBlue = Color(0xff000f89);
Color PhthaloGreen = Color(0xff123524);
Color PiggyPink = Color(0xfffddde6);
Color PineGreen = Color(0xff01796f);
Color Pink = Color(0xffffc0cb);
Color PinkFlamingo = Color(0xfffc74fd);
Color PinkSherbet = Color(0xfff78fa7);
Color PinkPearl = Color(0xffe7accf);
Color Pistachio = Color(0xff93c572);
Color Platinum = Color(0xffe5e4e2);
Color Plum = Color(0xffdda0dd);
Color PortlandOrange = Color(0xffff5a36);
Color PowderBlue = Color(0xffb0e0e6);
Color PrincetonOrange = Color(0xffff8f00);
Color PrussianBlue = Color(0xff003153);
Color PsychedelicPurple = Color(0xffdf00ff);
Color Puce = Color(0xffcc8899);
Color Pumpkin = Color(0xffff7518);
Color Purple = Color(0xff800080);
Color PurpleHeart = Color(0xff69359c);
Color PurpleMountainMajesty = Color(0xff9d81ba);
Color PurpleMountainsMajesty = Color(0xff9678b6);
Color PurplePizzazz = Color(0xfffe4eda);
Color PurpleTaupe = Color(0xff50404d);
Color Rackley = Color(0xff5d8aa8);
Color RadicalRed = Color(0xffff355e);
Color Raspberry = Color(0xffe30b5d);
Color RaspberryGlace = Color(0xff915f6d);
Color RaspberryPink = Color(0xffe25098);
Color RaspberryRose = Color(0xffb3446c);
Color RawSienna = Color(0xffd68a59);
Color RazzleDazzleRose = Color(0xffff33cc);
Color Razzmatazz = Color(0xffe3256b);
Color Red = Color(0xffff0000);
Color RedOrange = Color(0xffff5349);
Color RedBrown = Color(0xffa52a2a);
Color RedViolet = Color(0xffc71585);
Color RichBlack = Color(0xff004040);
Color RichCarmine = Color(0xffd70040);
Color RichElectricBlue = Color(0xff0892d0);
Color RichLilac = Color(0xffb666d2);
Color RichMaroon = Color(0xffb03060);
Color RifleGreen = Color(0xff414833);
Color RobinsEggBlue = Color(0xff1fcecb);
Color Rose = Color(0xffff007f);
Color RoseBonbon = Color(0xfff9429e);
Color RoseEbony = Color(0xff674846);
Color RoseGold = Color(0xffb76e79);
Color RoseMadder = Color(0xffe32636);
Color RosePink = Color(0xffff66cc);
Color RoseQuartz = Color(0xffaa98a9);
Color RoseTaupe = Color(0xff905d5d);
Color RoseVale = Color(0xffab4e52);
Color Rosewood = Color(0xff65000b);
Color RossoCorsa = Color(0xffd40000);
Color RosyBrown = Color(0xffbc8f8f);
Color RoyalAzure = Color(0xff0038a8);
Color RoyalBlue = Color(0xff4169e1);
Color RoyalFuchsia = Color(0xffca2c92);
Color RoyalPurple = Color(0xff7851a9);
Color Ruby = Color(0xffe0115f);
Color Ruddy = Color(0xffff0028);
Color RuddyBrown = Color(0xffbb6528);
Color RuddyPink = Color(0xffe18e96);
Color Rufous = Color(0xffa81c07);
Color Russet = Color(0xff80461b);
Color Rust = Color(0xffb7410e);
Color SacramentoStateGreen = Color(0xff00563f);
Color SaddleBrown = Color(0xff8b4513);
Color SafetyOrange = Color(0xffff6700);
Color Saffron = Color(0xfff4c430);
Color SaintPatrickBlue = Color(0xff23297a);
Color Salmon = Color(0xffff8c69);
Color SalmonPink = Color(0xffff91a4);
Color Sand = Color(0xffc2b280);
Color SandDune = Color(0xff967117);
Color Sandstorm = Color(0xffecd540);
Color SandyBrown = Color(0xfff4a460);
Color SandyTaupe = Color(0xff967117);
Color SapGreen = Color(0xff507d2a);
Color Sapphire = Color(0xff0f52ba);
Color SatinSheenGold = Color(0xffcba135);
Color Scarlet = Color(0xffff2400);
Color SchoolBusYellow = Color(0xffffd800);
Color ScreaminGreen = Color(0xff76ff7a);
Color SeaBlue = Color(0xff006994);
Color SeaGreen = Color(0xff2e8b57);
Color SealBrown = Color(0xff321414);
Color Seashell = Color(0xfffff5ee);
Color SelectiveYellow = Color(0xffffba00);
Color Sepia = Color(0xff704214);
Color Shadow = Color(0xff8a795d);
Color Shamrock = Color(0xff45cea2);
Color ShamrockGreen = Color(0xff009e60);
Color ShockingPink = Color(0xfffc0fc0);
Color Sienna = Color(0xff882d17);
Color Silver = Color(0xffc0c0c0);
Color Sinopia = Color(0xffcb410b);
Color Skobeloff = Color(0xff007474);
Color SkyBlue = Color(0xff87ceeb);
Color SkyMagenta = Color(0xffcf71af);
Color SlateBlue = Color(0xff6a5acd);
Color SlateGray = Color(0xff708090);
Color Smalt = Color(0xff003399);
Color SmokeyTopaz = Color(0xff933d41);
Color SmokyBlack = Color(0xff100c08);
Color Snow = Color(0xfffffafa);
Color SpiroDiscoBall = Color(0xff0fc0fc);
Color SpringBud = Color(0xffa7fc00);
Color SpringGreen = Color(0xff00ff7f);
Color SteelBlue = Color(0xff4682b4);
Color StilDeGrainYellow = Color(0xfffada5e);
Color Stizza = Color(0xff990000);
Color Stormcloud = Color(0xff008080);
Color Straw = Color(0xffe4d96f);
Color Sunglow = Color(0xffffcc33);
Color Sunset = Color(0xfffad6a5);
Color SunsetOrange = Color(0xfffd5e53);
Color Tan = Color(0xffd2b48c);
Color Tangelo = Color(0xfff94d00);
Color Tangerine = Color(0xfff28500);
Color TangerineYellow = Color(0xffffcc00);
Color Taupe = Color(0xff483c32);
Color TaupeGray = Color(0xff8b8589);
Color Tawny = Color(0xffcd5700);
Color TeaGreen = Color(0xffd0f0c0);
Color TeaRose = Color(0xfff4c2c2);
Color Teal = Color(0xff008080);
Color TealBlue = Color(0xff367588);
Color TealGreen = Color(0xff006d5b);
Color TerraCotta = Color(0xffe2725b);
Color Thistle = Color(0xffd8bfd8);
Color ThulianPink = Color(0xffde6fa1);
Color TickleMePink = Color(0xfffc89ac);
Color TiffanyBlue = Color(0xff0abab5);
Color TigerEye = Color(0xffe08d3c);
Color Timberwolf = Color(0xffdbd7d2);
Color TitaniumYellow = Color(0xffeee600);
Color Tomato = Color(0xffff6347);
Color Toolbox = Color(0xff746cc0);
Color Topaz = Color(0xffffc87c);
Color TractorRed = Color(0xfffd0e35);
Color TrolleyGrey = Color(0xff808080);
Color TropicalRainForest = Color(0xff00755e);
Color TrueBlue = Color(0xff0073cf);
Color TuftsBlue = Color(0xff417dc1);
Color Tumbleweed = Color(0xffdeaa88);
Color TurkishRose = Color(0xffb57281);
Color Turquoise = Color(0xff30d5c8);
Color TurquoiseBlue = Color(0xff00ffef);
Color TurquoiseGreen = Color(0xffa0d6b4);
Color TuscanRed = Color(0xff66424d);
Color TwilightLavender = Color(0xff8a496b);
Color TyrianPurple = Color(0xff66023c);
Color UaBlue = Color(0xff0033aa);
Color UaRed = Color(0xffd9004c);
Color UclaBlue = Color(0xff536895);
Color UclaGold = Color(0xffffb300);
Color UfoGreen = Color(0xff3cd070);
Color UpForestGreen = Color(0xff014421);
Color UpMaroon = Color(0xff7b1113);
Color UscCardinal = Color(0xff990000);
Color UscGold = Color(0xffffcc00);
Color Ube = Color(0xff8878c3);
Color UltraPink = Color(0xffff6fff);
Color Ultramarine = Color(0xff120a8f);
Color UltramarineBlue = Color(0xff4166f5);
Color Umber = Color(0xff635147);
Color UnitedNationsBlue = Color(0xff5b92e5);
Color UniversityOfCaliforniaGold = Color(0xffb78727);
Color UnmellowYellow = Color(0xffffff66);
Color UpsdellRed = Color(0xffae2029);
Color Urobilin = Color(0xffe1ad21);
Color UtahCrimson = Color(0xffd3003f);
Color Vanilla = Color(0xfff3e5ab);
Color VegasGold = Color(0xffc5b358);
Color VenetianRed = Color(0xffc80815);
Color Verdigris = Color(0xff43b3ae);
Color Vermilion = Color(0xffe34234);
Color Veronica = Color(0xffa020f0);
Color Violet = Color(0xffee82ee);
Color VioletBlue = Color(0xff324ab2);
Color VioletRed = Color(0xfff75394);
Color Viridian = Color(0xff40826d);
Color VividAuburn = Color(0xff922724);
Color VividBurgundy = Color(0xff9f1d35);
Color VividCerise = Color(0xffda1d81);
Color VividTangerine = Color(0xffffa089);
Color VividViolet = Color(0xff9f00ff);
Color WarmBlack = Color(0xff004242);
Color Waterspout = Color(0xff00ffff);
Color Wenge = Color(0xff645452);
Color Wheat = Color(0xfff5deb3);
Color White = Color(0xffffffff);
Color WhiteSmoke = Color(0xfff5f5f5);
Color WildStrawberry = Color(0xffff43a4);
Color WildWatermelon = Color(0xfffc6c85);
Color WildBlueYonder = Color(0xffa2add0);
Color Wine = Color(0xff722f37);
Color Wisteria = Color(0xffc9a0dc);
Color Xanadu = Color(0xff738678);
Color YaleBlue = Color(0xff0f4d92);
Color Yellow = Color(0xffffff00);
Color YellowOrange = Color(0xffffae42);
Color YellowGreen = Color(0xff9acd32);
Color Zaffre = Color(0xff0014a8);
Color ZinnwalditeBrown = Color(0xff2c1608);

//A huge list for you to traversal all colors above.
List<Color> colors = [
  AirForceBlue,
  AliceBlue,
  AlizarinCrimson,
  Almond,
  Amaranth,
  Amber,
  AmericanRose,
  Amethyst,
  AndroidGreen,
  AntiFlashWhite,
  AntiqueBrass,
  AntiqueFuchsia,
  AntiqueWhite,
  Ao,
  AppleGreen,
  Apricot,
  Aqua,
  Aquamarine,
  ArmyGreen,
  ArylideYellow,
  AshGrey,
  Asparagus,
  AtomicTangerine,
  Auburn,
  Aureolin,
  Aurometalsaurus,
  Awesome,
  Azure,
  AzureMist,
  BabyBlue,
  BabyBlueEyes,
  BabyPink,
  BallBlue,
  BananaMania,
  BananaYellow,
  BattleshipGrey,
  Bazaar,
  BeauBlue,
  Beaver,
  Beige,
  Bisque,
  Bistre,
  Bittersweet,
  Black,
  BlanchedAlmond,
  BleuDeFrance,
  BlizzardBlue,
  Blond,
  Blue,
  BlueBell,
  BlueGray,
  BlueGreen,
  BluePurple,
  BlueViolet,
  Blush,
  Bole,
  BondiBlue,
  Bone,
  BostonUniversityRed,
  BottleGreen,
  Boysenberry,
  BrandeisBlue,
  Brass,
  BrickRed,
  BrightCerulean,
  BrightGreen,
  BrightLavender,
  BrightMaroon,
  BrightPink,
  BrightTurquoise,
  BrightUbe,
  BrilliantLavender,
  BrilliantRose,
  BrinkPink,
  BritishRacingGreen,
  Bronze,
  Brown,
  BubbleGum,
  Bubbles,
  Buff,
  BulgarianRose,
  Burgundy,
  Burlywood,
  BurntOrange,
  BurntSienna,
  BurntUmber,
  Byzantine,
  Byzantium,
  CgBlue,
  CgRed,
  Cadet,
  CadetBlue,
  CadetGrey,
  CadmiumGreen,
  CadmiumOrange,
  CadmiumRed,
  CadmiumYellow,
  CafeAuLait,
  CafeNoir,
  CalPolyPomonaGreen,
  CambridgeBlue,
  Camel,
  CamouflageGreen,
  Canary,
  CanaryYellow,
  CandyAppleRed,
  CandyPink,
  Capri,
  CaputMortuum,
  Cardinal,
  CaribbeanGreen,
  Carmine,
  CarminePink,
  CarmineRed,
  CarnationPink,
  Carnelian,
  CarolinaBlue,
  CarrotOrange,
  Celadon,
  Celeste,
  CelestialBlue,
  Cerise,
  CerisePink,
  Cerulean,
  CeruleanBlue,
  Chamoisee,
  Champagne,
  Charcoal,
  Chartreuse,
  Cherry,
  CherryBlossomPink,
  Chestnut,
  Chocolate,
  ChromeYellow,
  Cinereous,
  Cinnabar,
  Cinnamon,
  Citrine,
  ClassicRose,
  Cobalt,
  CocoaBrown,
  Coffee,
  ColumbiaBlue,
  CoolBlack,
  CoolGrey,
  Copper,
  CopperRose,
  Coquelicot,
  Coral,
  CoralPink,
  CoralRed,
  Cordovan,
  Corn,
  CornellRed,
  Cornflower,
  CornflowerBlue,
  Cornsilk,
  CosmicLatte,
  CottonCandy,
  Cream,
  Crimson,
  CrimsonRed,
  CrimsonGlory,
  Cyan,
  Daffodil,
  Dandelion,
  DarkBlue,
  DarkBrown,
  DarkByzantium,
  DarkCandyAppleRed,
  DarkCerulean,
  DarkChestnut,
  DarkCoral,
  DarkCyan,
  DarkElectricBlue,
  DarkGoldenrod,
  DarkGray,
  DarkGreen,
  DarkJungleGreen,
  DarkKhaki,
  DarkLava,
  DarkLavender,
  DarkMagenta,
  DarkMidnightBlue,
  DarkOliveGreen,
  DarkOrange,
  DarkOrchid,
  DarkPastelBlue,
  DarkPastelGreen,
  DarkPastelPurple,
  DarkPastelRed,
  DarkPink,
  DarkPowderBlue,
  DarkRaspberry,
  DarkRed,
  DarkSalmon,
  DarkScarlet,
  DarkSeaGreen,
  DarkSienna,
  DarkSlateBlue,
  DarkSlateGray,
  DarkSpringGreen,
  DarkTan,
  DarkTangerine,
  DarkTaupe,
  DarkTerraCotta,
  DarkTurquoise,
  DarkViolet,
  DartmouthGreen,
  DavyGrey,
  DebianRed,
  DeepCarmine,
  DeepCarminePink,
  DeepCarrotOrange,
  DeepCerise,
  DeepChampagne,
  DeepChestnut,
  DeepCoffee,
  DeepFuchsia,
  DeepJungleGreen,
  DeepLilac,
  DeepMagenta,
  DeepPeach,
  DeepPink,
  DeepSaffron,
  DeepSkyBlue,
  Denim,
  Desert,
  DesertSand,
  DimGray,
  DodgerBlue,
  DogwoodRose,
  DollarBill,
  Drab,
  DukeBlue,
  EarthYellow,
  Ecru,
  Eggplant,
  Eggshell,
  EgyptianBlue,
  ElectricBlue,
  ElectricCrimson,
  ElectricCyan,
  ElectricGreen,
  ElectricIndigo,
  ElectricLavender,
  ElectricLime,
  ElectricPurple,
  ElectricUltramarine,
  ElectricViolet,
  ElectricYellow,
  Emerald,
  EtonBlue,
  Fallow,
  FaluRed,
  Famous,
  Fandango,
  FashionFuchsia,
  Fawn,
  Feldgrau,
  Fern,
  FernGreen,
  FerrariRed,
  FieldDrab,
  FireEngineRed,
  Firebrick,
  Flame,
  FlamingoPink,
  Flavescent,
  Flax,
  FloralWhite,
  FluorescentOrange,
  FluorescentPink,
  FluorescentYellow,
  Folly,
  ForestGreen,
  FrenchBeige,
  FrenchBlue,
  FrenchLilac,
  FrenchRose,
  Fuchsia,
  FuchsiaPink,
  Fulvous,
  FuzzyWuzzy,
  Gainsboro,
  Gamboge,
  GhostWhite,
  Ginger,
  Glaucous,
  Glitter,
  Gold,
  GoldenBrown,
  GoldenPoppy,
  GoldenYellow,
  Goldenrod,
  GrannySmithApple,
  Gray,
  GrayAsparagus,
  Green,
  GreenBlue,
  GreenYellow,
  Grullo,
  GuppieGreen,
  HalayaUbe,
  HanBlue,
  HanPurple,
  HansaYellow,
  Harlequin,
  HarvardCrimson,
  HarvestGold,
  HeartGold,
  Heliotrope,
  HollywoodCerise,
  Honeydew,
  HookerGreen,
  HotMagenta,
  HotPink,
  HunterGreen,
  Icterine,
  Inchworm,
  IndiaGreen,
  IndianRed,
  IndianYellow,
  Indigo,
  InternationalKleinBlue,
  InternationalOrange,
  Iris,
  Isabelline,
  IslamicGreen,
  Ivory,
  Jade,
  Jasmine,
  Jasper,
  JazzberryJam,
  Jonquil,
  JuneBud,
  JungleGreen,
  KuCrimson,
  KellyGreen,
  Khaki,
  LaSalleGreen,
  LanguidLavender,
  LapisLazuli,
  LaserLemon,
  LaurelGreen,
  Lava,
  Lavender,
  LavenderBlue,
  LavenderBlush,
  LavenderGray,
  LavenderIndigo,
  LavenderMagenta,
  LavenderMist,
  LavenderPink,
  LavenderPurple,
  LavenderRose,
  LawnGreen,
  Lemon,
  LemonYellow,
  LemonChiffon,
  LemonLime,
  LightCrimson,
  LightThulianPink,
  LightApricot,
  LightBlue,
  LightBrown,
  LightCarminePink,
  LightCoral,
  LightCornflowerBlue,
  LightCyan,
  LightFuchsiaPink,
  LightGoldenrodYellow,
  LightGray,
  LightGreen,
  LightKhaki,
  LightPastelPurple,
  LightPink,
  LightSalmon,
  LightSalmonPink,
  LightSeaGreen,
  LightSkyBlue,
  LightSlateGray,
  LightTaupe,
  LightYellow,
  Lilac,
  Lime,
  LimeGreen,
  LincolnGreen,
  Linen,
  Lion,
  Liver,
  Lust,
  MsuGreen,
  MacaroniAndCheese,
  Magenta,
  MagicMint,
  Magnolia,
  Mahogany,
  Maize,
  MajorelleBlue,
  Malachite,
  Manatee,
  MangoTango,
  Mantis,
  Maroon,
  Mauve,
  MauveTaupe,
  Mauvelous,
  MayaBlue,
  MeatBrown,
  MediumPersianBlue,
  MediumAquamarine,
  MediumBlue,
  MediumCandyAppleRed,
  MediumCarmine,
  MediumChampagne,
  MediumElectricBlue,
  MediumJungleGreen,
  MediumLavenderMagenta,
  MediumOrchid,
  MediumPurple,
  MediumRedViolet,
  MediumSeaGreen,
  MediumSlateBlue,
  MediumSpringBud,
  MediumSpringGreen,
  MediumTaupe,
  MediumTealBlue,
  MediumTurquoise,
  MediumVioletRed,
  Melon,
  MidnightBlue,
  MidnightGreen,
  MikadoYellow,
  Mint,
  MintCream,
  MintGreen,
  MistyRose,
  Moccasin,
  ModeBeige,
  MoonstoneBlue,
  MordantRed19,
  MossGreen,
  MountainMeadow,
  MountbattenPink,
  Mulberry,
  Munsell,
  Mustard,
  Myrtle,
  NadeshikoPink,
  NapierGreen,
  NaplesYellow,
  NavajoWhite,
  NavyBlue,
  NeonCarrot,
  NeonFuchsia,
  NeonGreen,
  NonPhotoBlue,
  NorthTexasGreen,
  OceanBoatBlue,
  Ochre,
  OfficeGreen,
  OldGold,
  OldLace,
  OldLavender,
  OldMauve,
  OldRose,
  Olive,
  OliveDrab,
  OliveGreen,
  Olivine,
  Onyx,
  OperaMauve,
  Orange,
  OrangeYellow,
  OrangePeel,
  OrangeRed,
  Orchid,
  OtterBrown,
  OuterSpace,
  OutrageousOrange,
  OxfordBlue,
  PacificBlue,
  PakistanGreen,
  PalatinateBlue,
  PalatinatePurple,
  PaleAqua,
  PaleBlue,
  PaleBrown,
  PaleCarmine,
  PaleCerulean,
  PaleChestnut,
  PaleCopper,
  PaleCornflowerBlue,
  PaleGold,
  PaleGoldenrod,
  PaleGreen,
  PaleLavender,
  PaleMagenta,
  PalePink,
  PalePlum,
  PaleRedViolet,
  PaleRobinEggBlue,
  PaleSilver,
  PaleSpringBud,
  PaleTaupe,
  PaleVioletRed,
  PansyPurple,
  PapayaWhip,
  ParisGreen,
  PastelBlue,
  PastelBrown,
  PastelGray,
  PastelGreen,
  PastelMagenta,
  PastelOrange,
  PastelPink,
  PastelPurple,
  PastelRed,
  PastelViolet,
  PastelYellow,
  Patriarch,
  PayneGrey,
  Peach,
  PeachPuff,
  PeachYellow,
  Pear,
  Pearl,
  PearlAqua,
  Peridot,
  Periwinkle,
  PersianBlue,
  PersianIndigo,
  PersianOrange,
  PersianPink,
  PersianPlum,
  PersianRed,
  PersianRose,
  Phlox,
  PhthaloBlue,
  PhthaloGreen,
  PiggyPink,
  PineGreen,
  Pink,
  PinkFlamingo,
  PinkSherbet,
  PinkPearl,
  Pistachio,
  Platinum,
  Plum,
  PortlandOrange,
  PowderBlue,
  PrincetonOrange,
  PrussianBlue,
  PsychedelicPurple,
  Puce,
  Pumpkin,
  Purple,
  PurpleHeart,
  PurpleMountainMajesty,
  PurpleMountainsMajesty,
  PurplePizzazz,
  PurpleTaupe,
  Rackley,
  RadicalRed,
  Raspberry,
  RaspberryGlace,
  RaspberryPink,
  RaspberryRose,
  RawSienna,
  RazzleDazzleRose,
  Razzmatazz,
  Red,
  RedOrange,
  RedBrown,
  RedViolet,
  RichBlack,
  RichCarmine,
  RichElectricBlue,
  RichLilac,
  RichMaroon,
  RifleGreen,
  RobinsEggBlue,
  Rose,
  RoseBonbon,
  RoseEbony,
  RoseGold,
  RoseMadder,
  RosePink,
  RoseQuartz,
  RoseTaupe,
  RoseVale,
  Rosewood,
  RossoCorsa,
  RosyBrown,
  RoyalAzure,
  RoyalBlue,
  RoyalFuchsia,
  RoyalPurple,
  Ruby,
  Ruddy,
  RuddyBrown,
  RuddyPink,
  Rufous,
  Russet,
  Rust,
  SacramentoStateGreen,
  SaddleBrown,
  SafetyOrange,
  Saffron,
  SaintPatrickBlue,
  Salmon,
  SalmonPink,
  Sand,
  SandDune,
  Sandstorm,
  SandyBrown,
  SandyTaupe,
  SapGreen,
  Sapphire,
  SatinSheenGold,
  Scarlet,
  SchoolBusYellow,
  ScreaminGreen,
  SeaBlue,
  SeaGreen,
  SealBrown,
  Seashell,
  SelectiveYellow,
  Sepia,
  Shadow,
  Shamrock,
  ShamrockGreen,
  ShockingPink,
  Sienna,
  Silver,
  Sinopia,
  Skobeloff,
  SkyBlue,
  SkyMagenta,
  SlateBlue,
  SlateGray,
  Smalt,
  SmokeyTopaz,
  SmokyBlack,
  Snow,
  SpiroDiscoBall,
  SpringBud,
  SpringGreen,
  SteelBlue,
  StilDeGrainYellow,
  Stizza,
  Stormcloud,
  Straw,
  Sunglow,
  Sunset,
  SunsetOrange,
  Tan,
  Tangelo,
  Tangerine,
  TangerineYellow,
  Taupe,
  TaupeGray,
  Tawny,
  TeaGreen,
  TeaRose,
  Teal,
  TealBlue,
  TealGreen,
  TerraCotta,
  Thistle,
  ThulianPink,
  TickleMePink,
  TiffanyBlue,
  TigerEye,
  Timberwolf,
  TitaniumYellow,
  Tomato,
  Toolbox,
  Topaz,
  TractorRed,
  TrolleyGrey,
  TropicalRainForest,
  TrueBlue,
  TuftsBlue,
  Tumbleweed,
  TurkishRose,
  Turquoise,
  TurquoiseBlue,
  TurquoiseGreen,
  TuscanRed,
  TwilightLavender,
  TyrianPurple,
  UaBlue,
  UaRed,
  UclaBlue,
  UclaGold,
  UfoGreen,
  UpForestGreen,
  UpMaroon,
  UscCardinal,
  UscGold,
  Ube,
  UltraPink,
  Ultramarine,
  UltramarineBlue,
  Umber,
  UnitedNationsBlue,
  UniversityOfCaliforniaGold,
  UnmellowYellow,
  UpsdellRed,
  Urobilin,
  UtahCrimson,
  Vanilla,
  VegasGold,
  VenetianRed,
  Verdigris,
  Vermilion,
  Veronica,
  Violet,
  VioletBlue,
  VioletRed,
  Viridian,
  VividAuburn,
  VividBurgundy,
  VividCerise,
  VividTangerine,
  VividViolet,
  WarmBlack,
  Waterspout,
  Wenge,
  Wheat,
  White,
  WhiteSmoke,
  WildStrawberry,
  WildWatermelon,
  WildBlueYonder,
  Wine,
  Wisteria,
  Xanadu,
  YaleBlue,
  Yellow,
  YellowOrange,
  YellowGreen,
  Zaffre,
  ZinnwalditeBrown
];
